-- top module
--

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;

entity TEST is
	port (
		LEDGN			: out   std_logic_vector(2 downto 0);	-- LED
		PUSHSWN			: in    std_logic;						-- push sw
		PWRONRSTN		: in    std_logic;						-- power on reset
		CLK50MIN		: in    std_logic;						-- clock input 50M osc
		CLKIN			: in    std_logic_vector( 6 downto 0);	-- clock input #2
		GPIO0_D			: inout std_logic_vector( 9 downto 0);	-- GPIO data
		GPIO1_D			: inout std_logic_vector(23 downto 0);	-- GPIO data
		GPIO2_D			: inout std_logic_vector(17 downto 0);	-- GPIO data
		GPIO3_D			: inout std_logic_vector(21 downto 0) 	-- GPIO data
	);
end TEST;

-- P4i`bvj
--  1:GND                   02:GND                 
--  3:LEDGN[0]    (pin  3)  04:GPIO0_D[ 0] (pin  4)
--  5:LEDGN[1]    (pin  7)  06:GPIO0_D[ 1] (pin  8)
--  7:LEDGN[2]    (pin  9)  08:GND                 
--  9:GND                   10:GND                 
-- 11:CLKIN[0]    (pin 18)  12:CLK50MIN    (pin 17)
-- 13:CLKIN[2]    (pin 22)  14:CLKIN[1]    (pin 21)
-- 15:GPIO0_D[ 2] (pin 25)  16:GPIO0_D[ 3] (pin 24)
-- 17:GPIO0_D[ 4] (pin 27)  18:GPIO0_D[ 5] (pin 26)
-- 19:VCC1.2V               20:VCC1.2V             
-- 21:GPIO0_D[ 6] (pin 30)  22:GPIO0_D[ 7] (pin 28)
-- 23:GPIO0_D[ 8] (pin 32)  24:GPIO0_D[ 9] (pin 31)
-- 25:GND                   26:GND                 
-- 27:VCC3.3V               28:VCC3.3V             

-- P1i`bvj
--  1:GPIO1_D[ 0] (pin 40)  02:GPIO1_D[ 1] (pin 41)
--  3:GPIO1_D[ 2] (pin 42)  04:GPIO1_D[ 3] (pin 43)
--  5:GPIO1_D[ 4] (pin 44)  06:GPIO1_D[ 5] (pin 45)
--  7:GPIO1_D[ 6] (pin 47)  08:GPIO1_D[ 7] (pin 48)
--  9:GPIO1_D[ 8] (pin 51)  10:GPIO1_D[ 9] (pin 52)
-- 11:GPIO1_D[10] (pin 53)  12:GPIO1_D[11] (pin 55)
-- 13:GPIO1_D[12] (pin 57)  14:GPIO1_D[13] (pin 58)
-- 15:GPIO1_D[14] (pin 59)  16:GPIO1_D[15] (pin 60)
-- 17:GPIO1_D[16] (pin 63)  18:GPIO1_D[17] (pin 64)
-- 19:GPIO1_D[18] (pin 65)  20:GPIO1_D[19] (pin 67)
-- 21:GPIO1_D[20] (pin 69)  22:GPIO1_D[21] (pin 70)
-- 23:GPIO1_D[22] (pin 71)  24:GPIO1_D[23] (pin 72)
-- 25:GND                   26:GND                 
-- 27:VCC3.3V               28:VCC3.3V             

-- P2i`bvEj
--  1:GND                   02:GND                 
--  3:PWRONRSTN   (pin 73)  04:GPIO2_D[ 0] (pin 74)
--  5:GPIO2_D[ 1] (pin 75)  06:GPIO2_D[ 2] (pin 76)
--  7:GPIO2_D[ 3] (pin 79)  08:GPIO2_D[ 4] (pin 80)
--  9:GPIO2_D[ 5] (pin 81)  10:GPIO2_D[ 6] (pin 86)
-- 11:GPIO2_D[ 7] (pin 87)  12:CLKIN[3]    (pin 88)
-- 13:CLKIN[4]    (pin 89)  14:CLKIN[5]    (pin 90)
-- 15:CLKIN[6]    (pin 91)  16:GPIO2_D[ 8] (pin 92)
-- 17:GPIO2_D[ 9] (pin 93)  18:GPIO2_D[10] (pin 94)
-- 19:GPIO2_D[11] (pin 96)  20:GPIO2_D[12] (pin 97)
-- 21:GPIO2_D[13] (pin 99)  22:GPIO2_D[14] (pin100)
-- 23:GPIO2_D[15] (pin101)  24:GPIO2_D[16] (pin103)
-- 25:GPIO2_D[17] (pin104)  26:GND                 
-- 27:GND                   28:VCC3.3V             

-- P3i`bvj
--  1:GND                   02:GND                 
--  3:GPIO3_D[ 0] (pin112)  04:GPIO3_D[ 1] (pin113)
--  5:GPIO3_D[ 2] (pin114)  06:GPIO3_D[ 3] (pin115)
--  7:GPIO3_D[ 4] (pin118)  08:GPIO3_D[ 5] (pin119)
--  9:GPIO3_D[ 6] (pin120)  10:GPIO3_D[ 7] (pin121)
-- 11:GPIO3_D[ 8] (pin122)  12:GPIO3_D[ 9] (pin125)
-- 13:GPIO3_D[10] (pin126)  14:GPIO3_D[11] (pin129)
-- 15:GPIO3_D[12] (pin132)  16:GPIO3_D[13] (pin133)
-- 17:GPIO3_D[14] (pin134)  18:GPIO3_D[15] (pin135)
-- 19:GPIO3_D[16] (pin136)  20:GPIO3_D[17] (pin137)
-- 21:GPIO3_D[18] (pin139)  22:GPIO3_D[19] (pin141)
-- 23:GPIO3_D[20] (pin142)  24:GPIO3_D[21] (pin143)
-- 25:PUSHSWN     (pin144)  26:GND                 
-- 27:GND                   28:VCC3.3V             


architecture RTL of TEST is

	signal cnt		: std_logic_vector(25 downto 0);
	signal cnt1s	: std_logic_vector(2 downto 0);

begin

	process (CLK50MIN,PUSHSWN)
	begin
		if (PUSHSWN = '0') then
			cnt <= (others => '0');
		elsif (CLK50MIN'event and CLK50MIN = '1') then
			if (cnt = 50*1000*1000-1) then
				cnt <= (others => '0');
			else
				cnt <= cnt + 1;
			end if;
		end if;
	end process;

	process (CLK50MIN,PUSHSWN)
	begin
		if (PUSHSWN = '0') then
			cnt1s <= (others => '0');
		elsif (CLK50MIN'event and CLK50MIN = '1') then
			if (cnt = 50*1000*1000-1) then
				cnt1s <= cnt1s + 1;
			end if;
		end if;
	end process;

	LEDGN(0) <= not cnt1s(0);
	LEDGN(1) <= not cnt1s(1);
	LEDGN(2) <= not cnt1s(2);


-- unused pin


end RTL;
